@@ -2,8 +2,8 @@ import functools
 import logging
 
 
-def params_check(fn=None, *, required: list = None, optional: list = None, debug=False):
-    logger = logging.getLogger('__params_check__')
+def params_check(fn=None, *, required: list = None, optional: list = None, debug=False, logger=None):
+    logger = logger or logging.getLogger('__params_check__')
     debug and logger.setLevel(logging.DEBUG)
 
     def _check_required(func_name: str, **kwargs):
